Class: Iup::BackgroundBox
- Includes:
- DynamicFillMethods
- Defined in:
- lib/wrapped/background-box.rb
Overview
Contains a child widget, but itself provides no visible decorations. Its intended use is within a ZBox or ExpanderBox.
Instance Attribute Summary
Attributes inherited from Widget
Instance Method Summary collapse
-
#clientoffset ⇒ Object
:attr_reader: clientoffset returns current offset of box in its client as “widthxheight”.
-
#clientsize ⇒ Object
:attr_reader: clientsize returns current size of box as “widthxheight”.
-
#expand ⇒ Object
:attr: expand Allows box to fill available space in indicated direction.
-
#initialize(widget) {|_self| ... } ⇒ BackgroundBox
constructor
Creates an instance of the background box.
Methods included from DynamicFillMethods
Methods inherited from Canvas
#action=, #activate, #arc, #background, #background=, #backopacity, #backopacity=, #begin_block, #border, #box, #canfocus, #chord, #clear, #cursor, #deactivate, #drawsize, #end_block, #fillmode, #fillmode=, #focus_cb=, #font, #foreground, #foreground=, #hatch, #hatch=, #init, #interiorstyle, #interiorstyle=, #keypress_cb=, #kill, #line, #linecap, #linecap=, #linejoin, #linejoin=, #linestyle, #linestyle=, #linewidth, #linewidth=, #mark, #marksize, #marksize=, #marktype, #marktype=, #motion_cb=, #nativefont=, #padding, #pathset, #pixel, #position, #rastersize, #rectangle, #redraw, #resize_cb=, #screenposition, #sector, #stipple, #text, #textalignment, #textalignment=, #textorientation, #textorientation=, #tip, #vectortext, #vectortext_charsize, #vectortext_charsize=, #vectortext_direction, #vectortext_fontsize, #vectortext_loadfont, #vectortext_size, #vertex, #viewport, #wheel_cb=, #window, #writemode, #writemode=
Methods included from ButtonCallback
Methods included from ScrollBarAttributes
#dx, #dx=, #dy, #dy=, #linex, #linex=, #liney, #liney=, #posx, #posx=, #posy, #posy=, #scroll_cb=, #scrollbar, #xautohide, #xmax, #xmax=, #xmin, #xmin=, #yautohide, #ymax, #ymax=, #ymin, #ymin=
Methods included from AttributeBuilders
#define_attribute, #define_id_attribute, #define_id_reader, #define_id_writer, #define_property_attribute, #define_property_reader, #define_property_writer, #define_reader, #define_writer
Methods included from DragDropAttributes
#dragbegin_cb=, #dragdata_cb=, #dragdatasize_cb=, #dragend_cb=, #dragsource, #dragsourcemove, #dragtypes, #dropdata_cb=, #dropmotion_cb=, #droptarget, #droptypes
Methods inherited from Widget
#active, #assign_handle, #bgcolor, #destroy, #enterwindow_cb=, #fgcolor, #font, #getfocus_cb=, #help_cb=, #k_any=, #killfocus_cb=, #leavewindow_cb=, #map_cb=, #maxsize, #minsize, #open_controls, #size, #unmap_cb=, #visible, #wid, #zorder
Methods included from CallbackSetter
Constructor Details
#initialize(widget) {|_self| ... } ⇒ BackgroundBox
Creates an instance of the background box. If a block is given, the new instance is yielded to it.
-
widget- the child widget to contain
14 15 16 17 18 19 |
# File 'lib/wrapped/background-box.rb', line 14 def initialize @handle = IupLib.IupBackgroundBox(.handle) # run any provided block on instance, to set up further attributes yield self if block_given? end |
Instance Method Details
#clientoffset ⇒ Object
:attr_reader: clientoffset returns current offset of box in its client as “widthxheight”.
24 |
# File 'lib/wrapped/background-box.rb', line 24 define_reader :clientoffset |
#clientsize ⇒ Object
:attr_reader: clientsize returns current size of box as “widthxheight”.
29 |
# File 'lib/wrapped/background-box.rb', line 29 define_reader :clientsize |
#expand ⇒ Object
:attr: expand Allows box to fill available space in indicated direction. Values ‘no’ / ‘horizontal’ / ‘vertical’ / ‘yes’.
35 |
# File 'lib/wrapped/background-box.rb', line 35 define_attribute :expand |