Module: Iup::ScrollBarAttributes

Extended by:
AttributeBuilders
Included in:
Canvas
Defined in:
lib/wrapped/scrollbar-attributes.rb

Overview

Attributes for widgets that permit a scrollbar.

Instance Method Summary collapse

Methods included from AttributeBuilders

define_attribute, define_id_attribute, define_id_reader, define_id_writer, define_property_attribute, define_property_reader, define_property_writer, define_reader, define_writer

Instance Method Details

#dxObject

--



19
20
21
# File 'lib/wrapped/scrollbar-attributes.rb', line 19

def dx
  IupLib.IupGetAttribute(@handle, 'DX').first.to_f
end

#dx=(val) ⇒ Object

:nodoc:



23
24
25
# File 'lib/wrapped/scrollbar-attributes.rb', line 23

def dx= val # :nodoc:
  IupLib.IupSetAttribute(@handle, 'DX', val.to_s)
end

#dyObject

--



33
34
35
# File 'lib/wrapped/scrollbar-attributes.rb', line 33

def dy
  IupLib.IupGetAttribute(@handle, 'DY').first.to_f
end

#dy=(val) ⇒ Object

:nodoc:



37
38
39
# File 'lib/wrapped/scrollbar-attributes.rb', line 37

def dy= val # :nodoc:
  IupLib.IupSetAttribute(@handle, 'DY', val.to_s)
end

#linexObject

--



126
127
128
# File 'lib/wrapped/scrollbar-attributes.rb', line 126

def linex
  IupLib.IupGetAttribute(@handle, 'LINEX').first.to_f
end

#linex=(val) ⇒ Object

:nodoc:



130
131
132
# File 'lib/wrapped/scrollbar-attributes.rb', line 130

def linex= val # :nodoc:
  IupLib.IupSetAttribute(@handle, 'LINEX', val.to_s)
end

#lineyObject

--



139
140
141
# File 'lib/wrapped/scrollbar-attributes.rb', line 139

def liney
  IupLib.IupGetAttribute(@handle, 'LINEY').first.to_f
end

#liney=(val) ⇒ Object

:nodoc:



143
144
145
# File 'lib/wrapped/scrollbar-attributes.rb', line 143

def liney= val # :nodoc:
  IupLib.IupSetAttribute(@handle, 'LINEY', val.to_s)
end

#posxObject

--



47
48
49
# File 'lib/wrapped/scrollbar-attributes.rb', line 47

def posx
  IupLib.IupGetAttribute(@handle, 'POSX').first.to_f
end

#posx=(val) ⇒ Object

:nodoc:



51
52
53
# File 'lib/wrapped/scrollbar-attributes.rb', line 51

def posx= val # :nodoc:
  IupLib.IupSetAttribute(@handle, 'POSX', val.to_s)
end

#posyObject

--



61
62
63
# File 'lib/wrapped/scrollbar-attributes.rb', line 61

def posy
  IupLib.IupGetAttribute(@handle, 'POSY').first.to_f
end

#posy=(val) ⇒ Object

:nodoc:



65
66
67
# File 'lib/wrapped/scrollbar-attributes.rb', line 65

def posy= val # :nodoc:
  IupLib.IupSetAttribute(@handle, 'POSY', val.to_s)
end

#scroll_cb=(callback) ⇒ Object

--



168
169
170
171
172
173
174
175
176
# File 'lib/wrapped/scrollbar-attributes.rb', line 168

def scroll_cb= callback
  unless callback.arity == 3
    raise ArgumentError, 'scroll_cb callback must take 3 arguments: (op, posx, posy)'
  end
  cb = Proc.new do |ih, op, posx, posy|
    callback.call op, posx, posy
  end
  define_callback cb, 'SCROLL_CB', :iff_i
end

#scrollbarObject

:attr: scrollbar Selects 'no' / 'horizontal' / 'vertical' / 'yes' (for both) scrollbars.



11
# File 'lib/wrapped/scrollbar-attributes.rb', line 11

define_attribute :scrollbar

#xautohideObject

:attr: xautohide If set, hides horizontal scrollbar if not required. Values 'yes' / 'no'.



150
# File 'lib/wrapped/scrollbar-attributes.rb', line 150

define_attribute :xautohide

#xmaxObject

--



100
101
102
# File 'lib/wrapped/scrollbar-attributes.rb', line 100

def xmax
  IupLib.IupGetAttribute(@handle, 'XMAX').first.to_f
end

#xmax=(val) ⇒ Object

:nodoc:



104
105
106
# File 'lib/wrapped/scrollbar-attributes.rb', line 104

def xmax= val # :nodoc:
  IupLib.IupSetAttribute(@handle, 'XMAX', val.to_s)
end

#xminObject

--



74
75
76
# File 'lib/wrapped/scrollbar-attributes.rb', line 74

def xmin 
  IupLib.IupGetAttribute(@handle, 'XMIN').first.to_f
end

#xmin=(val) ⇒ Object

:nodoc:



78
79
80
# File 'lib/wrapped/scrollbar-attributes.rb', line 78

def xmin= val # :nodoc:
  IupLib.IupSetAttribute(@handle, 'XMIN', val.to_s)
end

#yautohideObject

:attr: yautohide If set, hides vertical scrollbar if not required. Values 'yes' / 'no'.



155
# File 'lib/wrapped/scrollbar-attributes.rb', line 155

define_attribute :yautohide

#ymaxObject

--



113
114
115
# File 'lib/wrapped/scrollbar-attributes.rb', line 113

def ymax
  IupLib.IupGetAttribute(@handle, 'YMAX').first.to_f
end

#ymax=(val) ⇒ Object

:nodoc:



117
118
119
# File 'lib/wrapped/scrollbar-attributes.rb', line 117

def ymax= val # :nodoc:
  IupLib.IupSetAttribute(@handle, 'YMAX', val.to_s)
end

#yminObject

--



87
88
89
# File 'lib/wrapped/scrollbar-attributes.rb', line 87

def ymin 
  IupLib.IupGetAttribute(@handle, 'YMIN').first.to_f
end

#ymin=(val) ⇒ Object

:nodoc:



91
92
93
# File 'lib/wrapped/scrollbar-attributes.rb', line 91

def ymin= val # :nodoc:
  IupLib.IupSetAttribute(@handle, 'YMIN', val.to_s)
end