Class: Iup::Separator

Inherits:
Widget
  • Object
show all
Defined in:
lib/wrapped/separator.rb

Overview

A Separator is used within a menu, appears as a horizontal line.

Example

The following shows construction of a typical file menu, with a separating line before the exit item:

file_menu = Iup::Menu.new(
item_open, item_save, 
Iup::Separator.new, 
item_exit)

See also: Menu, MenuItem, SubMenu

Instance Attribute Summary

Attributes inherited from Widget

#handle

Instance Method Summary collapse

Methods inherited from Widget

#active, #assign_handle, #bgcolor, #destroy, #enterwindow_cb=, #fgcolor, #font, #getfocus_cb=, #help_cb=, #k_any=, #killfocus_cb=, #leavewindow_cb=, #map_cb=, #maxsize, #minsize, #open_controls, #size, #unmap_cb=, #visible, #wid, #zorder

Methods included from AttributeBuilders

#define_attribute, #define_id_attribute, #define_id_reader, #define_id_writer, #define_property_attribute, #define_property_reader, #define_property_writer, #define_reader, #define_writer

Methods included from CallbackSetter

#define_callback

Constructor Details

#initializeSeparator

Creates a new instance.



20
21
22
# File 'lib/wrapped/separator.rb', line 20

def initialize
  @handle = IupLib.IupSeparator
end