Class: Iup::Fill
Overview
Dynamically fills empty space. Its parent must be an HBox or VBox.
Instance Attribute Summary
Attributes inherited from Widget
Instance Method Summary collapse
-
#expand ⇒ Object
:attr_reader: expand ‘horizontal’ if in an HBox, or ‘vertical’ if in a VBox.
-
#initialize ⇒ Fill
constructor
Creates a new instance.
-
#position ⇒ Object
:attr_reader: position returns position in pixels within client window as “x,y”.
-
#rastersize ⇒ Object
:attr: rastersize Size of the widget, in pixels, value as “widthxheight”.
Methods inherited from Widget
#active, #assign_handle, #bgcolor, #destroy, #enterwindow_cb=, #fgcolor, #font, #getfocus_cb=, #help_cb=, #k_any=, #killfocus_cb=, #leavewindow_cb=, #map_cb=, #maxsize, #minsize, #open_controls, #size, #unmap_cb=, #visible, #wid, #zorder
Methods included from AttributeBuilders
#define_attribute, #define_id_attribute, #define_id_reader, #define_id_writer, #define_property_attribute, #define_property_reader, #define_property_writer, #define_reader, #define_writer
Methods included from CallbackSetter
Constructor Details
#initialize ⇒ Fill
Creates a new instance. Note that attributes must be set separately, not through a block.
9 10 11 |
# File 'lib/wrapped/fill.rb', line 9 def initialize @handle = IupLib.IupFill end |
Instance Method Details
#expand ⇒ Object
:attr_reader: expand ‘horizontal’ if in an HBox, or ‘vertical’ if in a VBox.
16 |
# File 'lib/wrapped/fill.rb', line 16 define_reader :expand |
#position ⇒ Object
:attr_reader: position returns position in pixels within client window as “x,y”.
21 |
# File 'lib/wrapped/fill.rb', line 21 define_reader :position |
#rastersize ⇒ Object
:attr: rastersize Size of the widget, in pixels, value as “widthxheight”.
26 |
# File 'lib/wrapped/fill.rb', line 26 define_attribute :rastersize |