Class: Iup::Frame
Overview
Instance Attribute Summary
Attributes inherited from Widget
Instance Method Summary collapse
-
#clientoffset ⇒ Object
:attr_reader: clientoffset Returns current offset of frame in its client as “widthxheight”.
-
#clientsize ⇒ Object
:attr_reader: clientsize Returns current size of frame as “widthxheight”.
-
#expand ⇒ Object
:attr: expand Allows frame to fill available space in indicated direction.
-
#initialize(widget) {|_self| ... } ⇒ Frame
constructor
Creates an instance of the frame.
-
#position ⇒ Object
:attr_reader: position returns position in pixels within client window as “x,y”.
-
#rastersize ⇒ Object
:attr: rastersize Size of the frame, in pixels, value as “widthxheight”.
-
#screenposition ⇒ Object
:attr_reader: screenposition returns position in pixels on screen as “x,y”.
-
#sunken ⇒ Object
:attr: sunken For frame with no title, gives a sunken appearance if set: values as ‘yes’ / ‘no’.
-
#title ⇒ Object
:attr: title Text displayed as frame title.
Methods inherited from Widget
#active, #assign_handle, #bgcolor, #destroy, #enterwindow_cb=, #fgcolor, #font, #getfocus_cb=, #help_cb=, #k_any=, #killfocus_cb=, #leavewindow_cb=, #map_cb=, #maxsize, #minsize, #open_controls, #size, #unmap_cb=, #visible, #wid, #zorder
Methods included from AttributeBuilders
#define_attribute, #define_id_attribute, #define_id_reader, #define_id_writer, #define_property_attribute, #define_property_reader, #define_property_writer, #define_reader, #define_writer
Methods included from CallbackSetter
Constructor Details
#initialize(widget) {|_self| ... } ⇒ Frame
Creates an instance of the frame. If a block is given, the new instance is yielded to it.
-
widget- the child widget to display.
19 20 21 22 23 24 |
# File 'lib/wrapped/frame.rb', line 19 def initialize @handle = IupLib.IupFrame(.handle) # run any provided block on instance, to set up further attributes yield self if block_given? end |
Instance Method Details
#clientoffset ⇒ Object
:attr_reader: clientoffset Returns current offset of frame in its client as “widthxheight”.
31 |
# File 'lib/wrapped/frame.rb', line 31 define_reader :clientoffset |
#clientsize ⇒ Object
:attr_reader: clientsize Returns current size of frame as “widthxheight”.
36 |
# File 'lib/wrapped/frame.rb', line 36 define_reader :clientsize |
#expand ⇒ Object
:attr: expand Allows frame to fill available space in indicated direction. Values ‘no’ / ‘horizontal’ / ‘vertical’ / ‘yes’.
42 |
# File 'lib/wrapped/frame.rb', line 42 define_attribute :expand |
#position ⇒ Object
:attr_reader: position returns position in pixels within client window as “x,y”.
47 |
# File 'lib/wrapped/frame.rb', line 47 define_reader :position |
#rastersize ⇒ Object
:attr: rastersize Size of the frame, in pixels, value as “widthxheight”.
52 |
# File 'lib/wrapped/frame.rb', line 52 define_attribute :rastersize |
#screenposition ⇒ Object
:attr_reader: screenposition returns position in pixels on screen as “x,y”.
57 |
# File 'lib/wrapped/frame.rb', line 57 define_reader :screenposition |
#sunken ⇒ Object
:attr: sunken For frame with no title, gives a sunken appearance if set: values as ‘yes’ / ‘no’.
62 |
# File 'lib/wrapped/frame.rb', line 62 define_attribute :sunken |
#title ⇒ Object
:attr: title Text displayed as frame title.
67 |
# File 'lib/wrapped/frame.rb', line 67 define_attribute :title |