Class: Iup::VBox
- Includes:
- DynamicFillMethods
- Defined in:
- lib/wrapped/vbox.rb
Overview
Instance Attribute Summary
Attributes inherited from Widget
Instance Method Summary collapse
-
#alignment ⇒ Object
:attr: alignment horizontal alignment of children, ‘aleft’ / ‘acenter’ / ‘aright’.
-
#clientoffset ⇒ Object
:attr_reader: clientoffset returns current offset of box in its client as “widthxheight”.
-
#clientsize ⇒ Object
:attr_reader: clientsize returns current size of box as “widthxheight”.
-
#expand ⇒ Object
:attr: expand Allows container to fill available space in indicated direction.
-
#expandchildren ⇒ Object
:attr: expandchildren Set to allow children to expand fully in horizontal direction, values as ‘yes’ / ‘no’.
-
#gap ⇒ Object
:attr: gap Number of pixels between children, default value of 0.
-
#homogeneous ⇒ Object
:attr: homogeneous Set to force all children to get equal vertical size, values as ‘yes’ / ‘no’.
-
#initialize(*widgets) {|_self| ... } ⇒ VBox
constructor
Creates an instance of the vbox.
-
#margin ⇒ Object
:attr: margin Margin in x and y directions, value as “mxn”.
-
#normalizesize ⇒ Object
:attr: normalsize Set to make natural size of children same, values as ‘yes’ / ‘no’.
-
#position ⇒ Object
:attr_reader: position returns position in pixels within client window as “x,y”.
-
#rastersize ⇒ Object
:attr: rastersize Size of the container, in pixels, value as “widthxheight”.
Methods included from DynamicFillMethods
Methods inherited from Widget
#active, #assign_handle, #bgcolor, #destroy, #enterwindow_cb=, #fgcolor, #font, #getfocus_cb=, #help_cb=, #k_any=, #killfocus_cb=, #leavewindow_cb=, #map_cb=, #maxsize, #minsize, #open_controls, #size, #unmap_cb=, #visible, #wid, #zorder
Methods included from AttributeBuilders
#define_attribute, #define_id_attribute, #define_id_reader, #define_id_writer, #define_property_attribute, #define_property_reader, #define_property_writer, #define_reader, #define_writer
Methods included from CallbackSetter
Constructor Details
#initialize(*widgets) {|_self| ... } ⇒ VBox
Creates an instance of the vbox. If a block is given, the new instance is yielded to it.
-
widgets- one or more child widgets
26 27 28 29 30 31 |
# File 'lib/wrapped/vbox.rb', line 26 def initialize * @handle = IupLib.IupVbox(*()) # run any provided block on instance, to set up further attributes yield self if block_given? end |
Instance Method Details
#alignment ⇒ Object
:attr: alignment horizontal alignment of children, ‘aleft’ / ‘acenter’ / ‘aright’
38 |
# File 'lib/wrapped/vbox.rb', line 38 define_attribute :alignment |
#clientoffset ⇒ Object
:attr_reader: clientoffset returns current offset of box in its client as “widthxheight”.
43 |
# File 'lib/wrapped/vbox.rb', line 43 define_reader :clientoffset |
#clientsize ⇒ Object
:attr_reader: clientsize returns current size of box as “widthxheight”.
48 |
# File 'lib/wrapped/vbox.rb', line 48 define_reader :clientsize |
#expand ⇒ Object
:attr: expand Allows container to fill available space in indicated direction. Values ‘no’ / ‘horizontal’ / ‘vertical’ / ‘yes’.
54 |
# File 'lib/wrapped/vbox.rb', line 54 define_attribute :expand |
#expandchildren ⇒ Object
:attr: expandchildren Set to allow children to expand fully in horizontal direction, values as ‘yes’ / ‘no’.
60 |
# File 'lib/wrapped/vbox.rb', line 60 define_attribute :expandchildren |
#gap ⇒ Object
:attr: gap Number of pixels between children, default value of 0.
65 |
# File 'lib/wrapped/vbox.rb', line 65 define_attribute :gap |
#homogeneous ⇒ Object
:attr: homogeneous Set to force all children to get equal vertical size, values as ‘yes’ / ‘no’.
71 |
# File 'lib/wrapped/vbox.rb', line 71 define_attribute :homogeneous |
#margin ⇒ Object
:attr: margin Margin in x and y directions, value as “mxn”.
76 |
# File 'lib/wrapped/vbox.rb', line 76 define_attribute :margin |
#normalizesize ⇒ Object
:attr: normalsize Set to make natural size of children same, values as ‘yes’ / ‘no’.
81 |
# File 'lib/wrapped/vbox.rb', line 81 define_attribute :normalizesize |
#position ⇒ Object
:attr_reader: position returns position in pixels within client window as “x,y”.
86 |
# File 'lib/wrapped/vbox.rb', line 86 define_reader :position |
#rastersize ⇒ Object
:attr: rastersize Size of the container, in pixels, value as “widthxheight”.
91 |
# File 'lib/wrapped/vbox.rb', line 91 define_attribute :rastersize |